@@ -1,3 +1,7 @@
+#' @export
+#' @name st_sample
+st_sample = function(x, size, ...) UseMethod("st_sample")
+
 #' sample points on or in (sets of) spatial features
 #'
 #' Sample points on or in (sets of) spatial features.
@@ -80,8 +84,13 @@
 #'  pts <- st_sample(x, kappa = 1, mu = 10, scale = 0.1, type = "Thomas") 
 #' }
 #' @export
-st_sample = function(x, size, ..., type = "random", exact = TRUE) {
-	x = st_geometry(x)
+#' @name st_sample
+st_sample.sf = function(x, size, ...) st_sample(st_geometry(x), size, ...)
+
+#' @export
+#' @name st_sample
+st_sample.sfc = function(x, size, ..., type = "random", exact = TRUE) {
+
 	if (!missing(size) && any(size %% 1 != 0))
 		stop("size should be an integer")
 	if (!missing(size) && length(size) > 1) { # recurse:
@@ -106,13 +115,23 @@ st_sample = function(x, size, ..., type = "random", exact = TRUE) {
 	res
 }
 
+#' @export
+#' @name st_sample
+st_sample.sfg = function(x, size, ...) {
+	st_sample(st_geometry(x), size, ...)
+}
+
 st_poly_sample = function(x, size, ..., type = "random",
                           offset = st_sample(st_as_sfc(st_bbox(x)), 1)[[1]]) {
 
 	if (type %in% c("hexagonal", "regular", "random")) {
 
-		if (type %in% c("regular", "hexagonal") && isTRUE(st_is_longlat(x)))
-			message_longlat("st_sample")
+		if (isTRUE(st_is_longlat(x))) {
+			if (type == "regular")
+				message_longlat("st_sample")
+			if (type == "hexagonal")
+				stop("hexagonal sampling on geographic coordinates not supported; consider projecting first")
+		}
 
 		a0 = as.numeric(st_area(st_make_grid(x, n = c(1,1))))
 		a1 = as.numeric(sum(st_area(x)))
